/*
Copyright Renaud GICQUEL 2005  
renaud.gicquel@s4e2.com

Ce logiciel est un programme informatique servant  modliser des systmes nergtiques.   

Ce logiciel est rgi par la licence CeCILL soumise au droit franais et respectant les principes de diffusion des logiciels libres. Vous pouvez utiliser, modifier et/ou redistribuer ce programme sous les conditions de la licence CeCILL telle que diffuse par le CEA, le CNRS et l'INRIA  sur le site "http://www.cecill.info".  

En contrepartie de l'accessibilit au code source et des droits de copie, de modification et de redistribution accords par cette licence, il n'est offert aux utilisateurs qu'une garantie limite.  Pour les mmes raisons, seule une responsabilit restreinte pse sur l'auteur du programme,  le titulaire des droits patrimoniaux et les concdants successifs.  

A cet gard  l'attention de l'utilisateur est attire sur les risques associs au chargement,   l'utilisation,   la modification et/ou au dveloppement et  la reproduction du logiciel par l'utilisateur tant  donn sa spcificit de logiciel libre, qui peut le rendre complexe   manipuler et qui le rserve donc  des dveloppeurs et des professionnels avertis possdant  des  connaissances  informatiques approfondies.  Les utilisateurs sont donc invits  charger  et  tester  l'adquation  du logiciel  leurs besoins dans des conditions permettant d'assurer la scurit de leurs systmes et ou de leurs donnes et, plus gnralement,   l'utiliser et l'exploiter dans les mmes conditions de scurit.   

Le fait que vous puissiez accder  cet en-tte signifie que vous avez  pris connaissance de la licence CeCILL, et que vous en avez accept les termes. 

This software is a computer program whose purpose is to model energy systems.  

This software is governed by the CeCILL  license under French law and abiding by the rules of distribution of free software.  You can  use,  modify and/ or redistribute the software under the terms of the CeCILL license as circulated by CEA, CNRS and INRIA at the following URL "http://www.cecill.info".   

As a counterpart to the access to the source code and  rights to copy, modify and redistribute granted by the license, users are provided only with a limited warranty  and the software's author,  the holder of the economic rights,  and the successive licensors  have only  limited liability.   

In this respect, the user's attention is drawn to the risks associated with loading,  using,  modifying and/or developing or reproducing the software by the user in light of its specific status of free software, that may mean  that it is complicated to manipulate,  and  that  also therefore means  that it is reserved for developers  and  experienced professionals having in-depth computer knowledge. Users are therefore encouraged to load and test the software's suitability as regards their requirements in conditions enabling the security of their systems and/or  data to be ensured and,  more generally, to use and operate it in the  same conditions as regards security.   

The fact that you are presently reading this means that you have had knowledge of the CeCILL license and that you accept its terms.  
*/
package extThopt;

import extThopt.*;

import java.util.*; 

import rg.corps.*; 
import rg.thopt.*;

import javax.swing.*;

/**
* This class enables you to add external dividers to Thermoptim.
*<p>
* To add one component, subclass ExtDivider by providing the appropriate methods
* in particular, getType() must return the component type as it will appear in
* the process list.
*<p>This class should not be modified
 * 
 * @author Renaud GICQUEL
*/
public class ExtDivider extends ExtNode
{
 
    DivExterne de;
 
    
    public ExtDivider (){
        super();
    }
    
    /**
    * dfinit l'identifiant de la classe
    * <p>
    * defines the class identifier
    * <p>
    * must be overridden by subclasses
    */
    public String getClassType(){
        return "divider";
    }
	
    /**
    * dfinit la description de la classe apparaissant dans le visualisateur
    * <p>
    * defines the class description shown in the viewer
    * <p>
    * should be overridden by subclasses
    */
	public String getClassDescription(){
	    return "external divider class\nbasic generic class";
	}
    
    /**
	* Charge la structure du diviseur
    *<p>
	* Loads the divider structure
    * <p>
    * not to be overridden by subclasses
	*/
    public void getDividerStructure(){
        getNodeStructure(de.getCompName());
    }
    /**
	* Met  jour le diviseur
	*<p>
	* Updates the divider
    * <p>
    * not to be overridden by subclasses
	**/
	protected void updateDivider(Vector[]vTransfo,Vector[]vPoints, double TGlobal, double hGlobal){
        Vector vTC=getUpdateVector(vTransfo,vPoints, TGlobal, hGlobal);
        de.de.updateDivider(vTC);
	}
	protected void updateDivider(Vector[]vTransfo,Vector[]vPoints, double TGlobal, double hGlobal, boolean displayValues){
        Vector vTC=getUpdateVector(vTransfo,vPoints, TGlobal, hGlobal, displayValues);
        de.de.updateDivider(vTC);
	}


	/**
	* Met  jour le thermocoupleur du type donn
    *<p>
	* Updates the thermocoupler of the type given
    * <p>
    * not to be overridden by subclasses
    * @param type String (thermocoupler ID)
    * @param Tin double (inlet temperature)
    * @param Tout double (outlet temperature)
    * @param Q double (heat load)
    * @param flow double (mass flow rate)
	*/
    protected void updateThermoCoupler(String type, double Tin, double Tout, double Q, double flow){
        de.de.updateThermoCouplers(getThermoCouplerVector(type, Tin, Tout, Q, flow));
    }

	/**
	* Met  jour le thermocoupleur du type donn
    *<p>
	* Updates the thermocoupler of the type given
    * <p>
    * not to be overridden by subclasses
    * @param type String (thermocoupler ID)
    * @param Tin double (inlet temperature)
    * @param Tout double (outlet temperature)
    * @param Q double (heat load)
    * @param flow double (mass flow rate)
    * @param isPinchFluid boolean (true if to be taken into account in optimization method)
    * @param DTmin double (pinch value)
	*/
    protected void updateThermoCoupler(String type, double Tin, double Tout, double Q, double flow, boolean isPinchFluid, double DTmin){
        de.de.updateThermoCouplers(getThermoCouplerVector(type, Tin, Tout, Q, flow));
    }
    
	/**
	* Imprime la valeur de UA du thermocoupleur du type donn
    *<p>
	* Prints the UA value of the thermocoupler of the type given
    * <p>
    * not to be overridden by subclasses
    * @param type String (thermocoupler ID)
	*/
	protected void getUA(String type){
        Vector vAbs=de.de.getThermoCouplerData(type);
        String nomAbs=(String)vAbs.elementAt(0);
	    
	    if((nomAbs!=null)&&(!nomAbs.equals(""))&&(!nomAbs.equals("null"))){
	        String[] args=new String[2];
	        args[0]="heatEx";//type of the element (see method getProperties(String[] args))
	        args[1]=nomAbs;//name of the process (see method getProperties(String[] args))
	        Vector vProp=proj.getProperties(args);
	        String hotFluidName=(String)vProp.elementAt(0);
	        String coldFluidName=(String)vProp.elementAt(1);
	        System.out.println(" hotFluidName "+hotFluidName+"  coldFluidName : "+coldFluidName);
	        Double f=(Double)vProp.elementAt(15);
	        double UA=f.doubleValue();
            System.out.println(" nom "+type+ " : "+nomAbs+"  UA : "+UA);
        }
	    
	}
	
	   public double[] getExergyInput(String type){//modRG exerg
	        Vector vAbs=de.de.getThermoCouplerData(type);
	        String nomAbs=(String)vAbs.elementAt(0);
	        double[] exergyInput={0,0};
		    
		    if((nomAbs!=null)&&(!nomAbs.equals(""))&&(!nomAbs.equals("null"))){
		        String[] args=new String[2];
		        args[0]="heatEx";//type of the element (see method getProperties(String[] args))
		        args[1]=nomAbs;//name of the process (see method getProperties(String[] args))
		        Vector vProp=proj.getProperties(args);
		        String connectedFluidName=(String)vProp.elementAt(0);
		        args[0]="process";
		        args[1]=connectedFluidName;
		        vProp=proj.getProperties(args);//connected process data
		        String inletPoint=(String)vProp.elementAt(1);
		        String outletPoint=(String)vProp.elementAt(2);     
		        Double f=(Double)vProp.elementAt(3);
		        double flow=f.doubleValue();
		        args[0]="project";
		        vProp=proj.getProperties(args);//project data
		        f=(Double)vProp.elementAt(2);
		        double T0exer=f.doubleValue();
		        
		        args[0]="point";
		        args[1]=inletPoint;
		        vProp=proj.getProperties(args);//inlet point data
		        f=(Double)vProp.elementAt(7);
		        double inletH=f.doubleValue();
		        f=(Double)vProp.elementAt(8);
		        double inletS=f.doubleValue();
		        f=(Double)vProp.elementAt(2);
		        double inletT=f.doubleValue();
		        args[1]=outletPoint;
		        vProp=proj.getProperties(args);//outlet point data
		        f=(Double)vProp.elementAt(7);
		        double outletH=f.doubleValue();
		        f=(Double)vProp.elementAt(8);
		        double outletS=f.doubleValue();
		        exergyInput[0]=flow*(inletH-outletH-T0exer*(inletS-outletS));
		        exergyInput[1]=flow*(inletH-outletH)*(1-T0exer/inletT);
	        
		        
	//	        System.out.println(" connectedFluidName "+connectedFluidName+ " inletPoint "+inletPoint+"  exergyInput[0] : "+exergyInput[0]);
	//	        System.out.println(" inletH "+inletH+ " inletT "+inletT+"  outletH : "+outletH+"  exergyInput[1] : "+exergyInput[1]);
	        }
		    return exergyInput;

	    }	

    /*
    public double[] getExergyBalance(String[]args){//modRG exerg
        double[] exergyBalance=new double[7];
        exergyBalance[0]=0;//tauPlus_value
        exergyBalance[1]=0;//DeltaXhPlus_value
        exergyBalance[2]=0;//xqPlus_value
        exergyBalance[3]=0;//tauProduct_value
        exergyBalance[4]=0;//deltaXhProduct_value
        exergyBalance[5]=0.5;//etaExer_value
        exergyBalance[6]=0;//deltaXhi_value
        if(exergyType.equals("not defined")){
	        String message="Watch out! Component "+de.getName()+" exergy balance is not implemented"; 
	        JOptionPane.showMessageDialog(new JFrame(),message);
            
        }
        return exergyBalance;
    }*/

}